---
title: 애플페이 서비스 이용안내
category: 결제서비스 (채널설정 및 이용안내) > 결제유형 > 간편결제
tags:
  - 간편결제
searchTags:
  - 간편결제
  - apple pay
  - 애플페이
datetime: 2024-11-11T05:59:07.351Z
---

### **이제 포트원을 통해 Apple pay 이용이 가능합니다**

<Callout content="이제 포트원을 통해서도 애플페이 결제를 이용하실 수 있습니다.
포트원을 통해 KCP, 토스페이먼츠, KG이니시스에서 제공하는 Apple pay를 바로 경험해보세요!" />

### **\[지원 가능한 조건]**

- 지원PG사 :  KCP , (구)토스페이먼츠 , (신)토스페이먼츠, KG이니시스, (신)나이스페이먼츠
- 카드 : 현대카드 (그외 국내 발행 카드사 및 해외 발행카드 미지원)
- 결제방식 : 일반결제 (정기결제 미지원)

### **\[PG사별 이용방법]**

<Callout content="현재 워드프레스는 직접 호출방식 지원이 어렵습니다." icon="💡" />

<Highlight text="KCP" />

<Indent level="1">

- **수수료**\
  \- 카드 결제수수료율과 동일\
  (기존 가맹점의 경우 카드결제수수료율과 동일하게 적용)
- **연동 지원방식**\
  \-  KCP 결제창 내 선택가능\
  \- 애플페이 직접 호출 가능
- **신청방법**\
  \- 기존 가맹점 : [기존 KCP 상점관리자페이지](https://admin8.kcp.co.kr/assist/login.LoginAction.do) > (우측상단) \[질문하기] > 추가서비스 > 결제수단:신용카드 or ’고객센터 > 질문하기 > 추가서비스 > 결제수단 : 신용카드’ (_신청시 결제창을 통한 방식인지, 직접호출 방식인지 KCP측으로 전달필요_)\
  \- 신규 가맹점 : PG 서비스 가입 신청 시, 간편결제를 포함하여 신청
- **연동 유의사항**\
  \- `Mobile Safari 한하여 지원가능`
- **연동방식**\
  \- PG사 결제창 화면 내에서 이용 \
  **<결제창 호출시 pay method : card>**\
  \- 애플페이 직접 호출\
  **<결제창 호출시 pay method : `applepay`>**

</Indent>

<Highlight text="(구)토스페이먼츠" />

<Indent level="1">

- **수수료**\
  \- 카드 결제수수료율과 동일\
  (기존 가맹점의 경우 카드결제수수료율과 동일하게 적용)
- **연동 지원방식**\
  \-  토스페이먼츠 결제창 내 선택가능\
  \- 애플페이 직접 호출 가능
- **신청방법**\
  \- 기존 가맹점 : 상점관리자(신용카드사 셋팅된 MID 기준) > 이용정보 > 결제⋅부가서비스 > 이용서비스, 간편결제 변경하기를 통해 신청\
  \- 신규 가맹점 : PG 서비스 가입 신청 시, 간편결제를 포함하여 신청
- **연동 유의사항**\
  \- `PC, Mobile 모두 Safari 한하여 지원가능`
- **연동방식**\
  \- PG사 결제창 화면 내에서 이용 \
  **<결제창 호출시 pay method : card>**\
  \- 애플페이 직접 호출\
  **<결제창 호출시 pay method : `applepay`>**

</Indent>

<Highlight text="(신)토스페이먼츠" />

<Indent level="1">

- **수수료**\
  \- 카드 결제수수료율과 동일\
  (기존 가맹점의 경우 카드결제수수료율과 동일하게 적용)
- **연동 지원방식**\
  \-  토스페이먼츠 결제창 내 선택가능\
  \- 애플페이 직접 호출 가능
- **신청방법**\
  \- 기존 가맹점 : 상점관리자(신용카드사 이용중인 MID 기준) > 이용정보 > 결제⋅부가서비스 > 이용서비스, 간편결제 변경하기를 통해 신청\
  \- 신규 가맹점 : PG 서비스 가입 신청 시, 간편결제를 포함하여 신청
- **연동 유의사항**\
  \- `PC, Mobile 모두 Safari 한하여 지원가능`
- **연동방식**\
  \- PG사 결제창 화면 내에서 이용 \
  **<결제창 호출시 pay method : card>**\
  \- 애플페이 직접 호출\
  **<결제창 호출시 pay method : `applepay`>**

</Indent>

<Highlight text="(신)나이스페이먼츠" />

<Indent level="1">

- **수수료**\
  \- 카드 결제수수료율과 동일\
  (기존 가맹점의 경우 카드결제수수료율과 동일하게 적용)
- **연동 지원방식**\
  \-  나이스페이먼츠 결제창 내 선택가능\
  \- 애플페이 직접 호출 가능
- **신청방법**\
  \- 기존 가맹점 : 나이스페이 고객센터 혹은 포트원 고객센터를 통해 애플페이 서비스 별도 신청\
  \- 신규 가맹점 : 포트원 관리자콘솔 내 신청시 ‘메모’란에  애플페이 서비스 신청  기입
- **연동 유의사항**\
  \- `Mobile Safari 한하여 지원가능`
- **연동방식**\
  \- PG사 결제창 화면 내에서 이용 \
  **<결제창 호출시 pay method : card>**\
  \- 애플페이 직접 호출\
  **<결제창 호출시 pay method : `applepay`>**

</Indent>

<Highlight text="KG이니시스" />

<Indent level="1">

- **수수료**\
  \- 카드 결제수수료율과 동일\
  (기존 가맹점의 경우 카드결제수수료율과 동일하게 적용)
- **연동 지원방식**\
  \-  토스페이먼츠 결제창 내 선택가능\
  \- 애플페이 직접 호출 가능
- **신청방법**\
  \- 기존 가맹점 : [KG이니시스 상점관리자](https://iniweb.inicis.com/security/login.do) (신용카드 이용중인 MID 기준) > 변경/추가 > 정보변경 및 서비스 추가 > 1.2 지불수단 추가 및 변경 > 1.2.1 지불수단 추가 및 변경 > 6. 간편결제 > Apple pay \[사용] 선택 후 신청하기\
  \- 신규 가맹점 : PG 서비스 가입 신청 시, 간편결제를 포함하여 신청
- **연동 유의사항**\
  \- `PC, Mobile 모두 Safari 한하여 지원가능`
- **연동방식**\
  \- PG사 결제창 화면 내에서 이용 \
  **<결제창 호출시 pay method : card>**\
  \- 애플페이 직접 호출\
  **<결제창 호출시 pay method : `applepay`>**

</Indent>

### **\[연동방식별 화면 미리보기]**

- PG사 결제창을 통해 연동하기



- 애플페이 직접 호출하기

